

set -ex



test -f ${PREFIX}/include/f2c/f2c.h
test -f ${PREFIX}/bin/f2c
test -f ${PREFIX}/lib/libf2c.a
test -f ${PREFIX}/lib/libf2c.so
f2c --version
f2c test_main.f && ${CC} test_main.c -L${PREFIX}/lib -lf2c -lm -I${PREFIX}/include -o test_main -Wl,-rpath,${PREFIX}/lib && ./test_main
exit 0
